@@ -1,6 +1,5 @@
 """
-Classes that describe collections of droplets, i.e. emulsions, and their
-temporal dynamics.
+Classes describing collections of droplets, i.e. emulsions, and their temporal dynamics.
 
 
 .. autosummary::
@@ -18,7 +17,6 @@ from __future__ import annotations
 import json
 import logging
 import math
-from typing import List  # @UnusedImport
 from typing import (
     TYPE_CHECKING,
     Any,
@@ -26,6 +24,7 @@ from typing import (
     Dict,
     Generator,
     Iterator,
+    List,
     Optional,
     Sequence,
     Tuple,
@@ -60,7 +59,7 @@ class Emulsion(list):
 
     def __init__(
         self,
-        droplets: DropletSequence = None,
+        droplets: Optional[DropletSequence] = None,
         grid: Optional[GridBase] = None,
         copy: bool = True,
     ):
@@ -124,9 +123,9 @@ class Emulsion(list):
 
         Args:
             min_radius (float):
-                The minimal radius of the droplets that are retained. Droplets
-                with exactly min_radius are removed, so `min_radius == 0` can be
-                used to filter vanished droplets.
+                The minimal radius of the droplets that are retained. Droplets with
+                exactly min_radius are removed, so `min_radius == 0` can be used to
+                filter vanished droplets.
         """
         droplets = [droplet.copy() for droplet in self if droplet.radius > min_radius]
         return self.__class__(
@@ -211,7 +210,7 @@ class Emulsion(list):
 
         Args:
             dataset:
-                an HDF5 dataset from which the data of the emulsion is read
+                An HDF5 dataset from which the data of the emulsion is read
             grid (:class:`pde.grids.base.GridBase`):
                 The grid on which the droplets are defined. This information is required
                 to measure distances between droplets.
@@ -291,8 +290,8 @@ class Emulsion(list):
     def interface_width(self) -> Optional[float]:
         """float: the average interface width across all droplets
 
-        This averages the interface widths of the individual droplets weighted
-        by their surface area, i.e., the amount of interface
+        This averages the interface widths of the individual droplets weighted by their
+        surface area, i.e., the amount of interface.
         """
 
         width, area = 0.0, 0.0
@@ -320,14 +319,14 @@ class Emulsion(list):
         return sum((droplet.bbox for droplet in self[1:]), self[0].bbox)  # type: ignore
 
     def get_phasefield(
-        self, grid: GridBase = None, label: Optional[str] = None
+        self, grid: Optional[GridBase] = None, label: Optional[str] = None
     ) -> ScalarField:
         """create a phase field representing a list of droplets
 
         Args:
             grid (:class:`pde.grids.base.GridBase`):
-                The grid on which the phase field is created. If omitted, the
-                grid associated with the emulsion is used.
+                The grid on which the phase field is created. If omitted, the grid
+                associated with the emulsion is used.
             label (str):
                 Optional label for the returned scalar field
 
@@ -355,10 +354,10 @@ class Emulsion(list):
         The emulsions is modified in-place.
 
         Args:
-            min_radius (float): The minimal radius of the droplets that are
-                retained. Droplets with exactly min_radius are removed, so
-                `min_radius == 0` can be used to filter vanished droplets. The
-                default value does not remove any droplets
+            min_radius (float):
+                The minimal radius of the droplets that are retained. Droplets with
+                exactly min_radius are removed, so `min_radius == 0` can be used to
+                filter vanished droplets. The default value does not remove any droplets
         """
         for i in reversed(range(len(self))):
             if self[i].radius <= min_radius:
@@ -368,9 +367,9 @@ class Emulsion(list):
         """return the pairwise distance between droplets
 
         Args:
-            subtract_radius (bool): determines whether the distance is measured
-                from interface to interface (for round droplets) or center to
-                center.
+            subtract_radius (bool):
+                determines whether the distance is measured from interface to interface
+                (for round droplets) or center to center.
 
         Returns:
             :class:`~numpy.ndarray`: a matrix with the distances between all droplets
@@ -401,13 +400,15 @@ class Emulsion(list):
     def get_neighbor_distances(self, subtract_radius: bool = False) -> np.ndarray:
         """calculates the distance of each droplet to its nearest neighbor
 
-        Warning: Nearest neighbors are defined by comparing the distances
-        between the centers of the droplets, not their surfaces.
+        Warning:
+            Nearest neighbors are defined by comparing the distances between the centers
+            of the droplets, not their surfaces.
 
         Args:
-            subtract_radius (bool): Determines whether to subtract the radius
-                from the distance, i.e., whether to return the distance between
-                the surfaces instead of the positions
+            subtract_radius (bool):
+                Determines whether to subtract the radius from the distance, i.e.,
+                whether to return the distance between the surfaces instead of the
+                positions
 
         Returns:
             :class:`~numpy.ndarray`: a vector with a distance for each droplet
@@ -437,15 +438,16 @@ class Emulsion(list):
     def remove_overlapping(self, min_distance: float = 0) -> None:
         """remove all droplets that are overlapping.
 
-        If a pair of overlapping droplets was found, the smaller one of these
-        is removed from the current emulsion. This method modifies the emulsion
-        in place and thus does not return anything.
+        If a pair of overlapping droplets was found, the smaller one of these is removed
+        from the current emulsion. This method modifies the emulsion in place and thus
+        does not return anything.
 
         Args:
-            min_distance (float): The minimal distance droplets need to be
-                apart. The default value of 0 corresponds to just remove
-                overlapping droplets. Larger values ensure that droplets keep a
-                distance, while negative values allow for some overlap.
+            min_distance (float):
+                The minimal distance droplets need to be apart. The default value of `0`
+                corresponds to just remove overlapping droplets. Larger values ensure
+                that droplets keep a distance, while negative values allow for some
+                overlap.
         """
         # filter duplicates until there are none left
         dists = self.get_pairwise_distances(subtract_radius=True)
@@ -470,9 +472,13 @@ class Emulsion(list):
         """float: the total volume of all droplets"""
         return sum(droplet.volume for droplet in self)  # type: ignore
 
-    def get_size_statistics(self) -> Dict[str, float]:
+    def get_size_statistics(self, incl_vanished: bool = True) -> Dict[str, float]:
         """determine size statistics of the current emulsion
 
+        Args:
+            incl_vanished (bool):
+                Whether to include droplets with vanished radii
+
         Returns:
             dict: a dictionary with various size statistics
         """
@@ -485,10 +491,15 @@ class Emulsion(list):
                 "volume_std": math.nan,
             }
 
-        radii = [droplet.radius for droplet in self]
-        volumes = [droplet.volume for droplet in self]
+        if incl_vanished:
+            radii = [droplet.radius for droplet in self]
+            volumes = [droplet.volume for droplet in self]
+        else:
+            radii = [droplet.radius for droplet in self if droplet.radius > 0]
+            volumes = [droplet.volume for droplet in self if droplet.radius > 0]
+
         return {
-            "count": len(self),
+            "count": len(radii),
             "radius_mean": np.mean(radii),
             "radius_std": np.std(radii),
             "volume_mean": np.mean(volumes),
@@ -499,10 +510,10 @@ class Emulsion(list):
     def plot(
         self,
         ax,
-        field: ScalarField = None,
-        image_args: Dict[str, Any] = None,
+        field: Optional[ScalarField] = None,
+        image_args: Optional[Dict[str, Any]] = None,
         repeat_periodically: bool = True,
-        color_value: Callable = None,
+        color_value: Optional[Callable] = None,
         cmap=None,
         norm=None,
         colorbar: Union[bool, str] = True,
@@ -546,6 +557,9 @@ class Emulsion(list):
         Returns:
             :class:`~pde.tools.plotting.PlotReference`: Information about the plot
         """
+        if len(self) == 0:
+            # empty emulsions can be plotted in all dimensions :)
+            return PlotReference(ax, [], {})
         if self.dim is None or self.dim <= 1:
             raise NotImplementedError(
                 f"Plotting emulsions in {self.dim} dimensions is not implemented."
@@ -584,12 +598,15 @@ class Emulsion(list):
             ax.set_ylim(*bounds[1])
             ax.set_aspect("equal")
 
+        # determine non-vanishing droplets
+        drops_finite = [droplet for droplet in self if droplet.radius > 0]
+
         # determine the color of all droplets
         if color_value is not None:
             import matplotlib.pyplot as plt
 
             # determine the scalar values associated with all droplets
-            values = np.array([color_value(droplet) for droplet in self])
+            values = np.array([color_value(droplet) for droplet in drops_finite])
 
             # and map them to colors
             mapper = plt.cm.ScalarMappable(norm=norm, cmap=cmap)
@@ -600,19 +617,19 @@ class Emulsion(list):
                 logger.warning("`color` is overwritten by `color_value`.")
 
         else:
-            colors = [kwargs.pop("color", None)] * len(self)
+            colors = [kwargs.pop("color", None)] * len(drops_finite)
 
         # get patches representing all droplets
         if grid is None or not repeat_periodically:
             # plot only the droplets themselves
             patches = [
                 droplet._get_mpl_patch(dim=2, color=color, **kwargs)
-                for droplet, color in zip(self, colors)
+                for droplet, color in zip(drops_finite, colors)
             ]
         else:
             # plot droplets also in their mirror positions
             patches = []
-            for droplet, color in zip(self, colors):
+            for droplet, color in zip(drops_finite, colors):
                 for p in grid.iter_mirror_points(
                     droplet.position, with_self=True, only_periodic=True
                 ):
@@ -669,10 +686,7 @@ class EmulsionTimeCourse:
             self.times = list(times)
 
         if len(self.times) != len(self.emulsions):
-            raise ValueError(
-                "The list of emulsions and the list of times need "
-                "to have the same length"
-            )
+            raise ValueError("Lists of emulsions and times must have same length")
 
     def append(
         self, emulsion: Emulsion, time: Optional[float] = None, copy: bool = True
@@ -680,10 +694,12 @@ class EmulsionTimeCourse:
         """add an emulsion to the list
 
         Args:
-            emulsions (Emulsion): An :class:`Emulsion` instance that is added
-                to the time course
-            time (float): The time point associated with this emulsion
-            copy (bool): Whether to copy the emulsion
+            emulsions (Emulsion):
+                An :class:`Emulsion` instance that is added to the time course
+            time (float):
+                The time point associated with this emulsion
+            copy (bool):
+                Whether to copy the emulsion
         """
         emulsion = Emulsion(emulsion)  # make sure this is an emulsion
 
@@ -745,7 +761,11 @@ class EmulsionTimeCourse:
 
     @classmethod
     def from_storage(
-        cls, storage: StorageBase, refine: bool = False, progress: bool = None, **kwargs
+        cls,
+        storage: StorageBase,
+        refine: bool = False,
+        progress: Optional[bool] = None,
+        **kwargs,
     ) -> "EmulsionTimeCourse":
         r"""create an emulsion time course from a stored phase field
 
@@ -813,7 +833,7 @@ class EmulsionTimeCourse:
                 )
         return obj
 
-    def to_file(self, path: str, info: InfoDict = None) -> None:
+    def to_file(self, path: str, info: Optional[InfoDict] = None) -> None:
         """store data in hdf5 file
 
         The data can be read using the classmethod :meth:`EmulsionTimeCourse.from_file`.
